@@ -70,6 +70,22 @@ public:
 
 	qpwgraph_patchbay *patchbay() const;
 
+	// Patchbay auto-pin accessors.
+	void setPatchbayAutoPin(bool on);
+	bool isPatchbayAutoPin() const;
+
+	// Patchbay edit-mode accessors.
+	void setPatchbayEdit(bool on);
+	bool isPatchbayEdit() const;
+
+	void patchbayEdit();
+
+	bool canPatchbayPin() const;
+	bool canPatchbayUnpin() const;
+
+	void patchbayPin();
+	void patchbayUnpin();
+
 	// Canvas methods.
 	void addItem(qpwgraph_item *item);
 	void removeItem(qpwgraph_item *item);
@@ -235,6 +251,8 @@ private:
 	QSettings  *m_settings;
 
 	qpwgraph_patchbay *m_patchbay;
+	bool m_patchbay_edit;
+	bool m_patchbay_autopin;
 
 	QList<QGraphicsItem *> m_selected;
 	int m_selected_nodes;
