@@ -103,7 +103,11 @@ protected slots:
 	void patchbayActivated(bool on);
 	void patchbayExclusive(bool on);
 
-	void patchbayScan();
+	void patchbayEdit(bool on);
+	void patchbayPin();
+	void patchbayUnpin();
+
+	void patchbayAutoPin(bool on);
 
 	// Main menu slots.
 	void viewMenubar(bool on);
@@ -156,8 +160,9 @@ protected:
 	QString patchbayFileExt() const;
 	QString patchbayFileFilter() const;
 
-	// Whether we can close current patchbay.
+	// Whether we can close/quit current patchbay.
 	bool patchbayQueryClose();
+	bool patchbayQueryQuit();
 
 	// Context-menu event handler.
 	void contextMenuEvent(QContextMenuEvent *event);
